#ifndef LIBDMIFS_H
#define LIBDMIFS_H

/**
 * dmi_hdata - information of dmi entry header
 * type: type of dmi entry
 * length: length of formated area of dmi entry
 * data: pointer to whole raw dmi entry data
 */
struct dmi_hdata {
	unsigned char type;
	unsigned char length;
	unsigned short handle;
	unsigned char *data;
};

/**
 * dmi_entry - holds information about dmi entry
 * next: internal in list pointer
 * h: dmi header data, including raw data
 * position: position within the dmi table
 * d_name: dirctory entry name in sysfs
 */
struct dmi_entry {
	struct dmi_entry *next;
	struct dmi_hdata h;
	unsigned int position;
	char *d_name;
};

/**
 * dmi_table - contains whole information about smbios/dmi tables
 * @smbios: pointer to raw data of smbios table
 * @dmi_count: number of dmi entries in dmi table
 * @dmi_size: length of dmi table in bytes
 * @dmi_list: single list of dmi table entries, raw data of which contiguously
 *	situated in memnory. The list can be used to take a pointer to raw data
 *	of whole dmi table.
 */
struct dmi_table {
	unsigned char smbios[32];
	unsigned int dmi_count;
	unsigned int dmi_size;
	struct dmi_entry *dmi_list;
};

int dmifs_is_exist(void);
struct dmi_table *dmi_get_table(void);
int dmi_put_table(struct dmi_table *dt);
void *dmi_get_raw_data(struct dmi_entry *dmi_list);
struct dmi_entry *dmi_get_entry_by_handle(struct dmi_entry *dmi_list,
					  int handle);
struct dmi_entry *dmi_get_next_entry_by_type(struct dmi_entry *dmi_entry,
					     unsigned char type);

#endif
